@@ -1,5 +1,5 @@
 #
-# $Id: Ssh.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Ssh.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
 #
 # client::ssh Brik
 #
@@ -7,14 +7,12 @@ package Metabrik::Client::Ssh;
 use strict;
 use warnings;
 
-use base qw(Metabrik::System::Package);
+use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 887d85a7f604 $',
+      tags => [ qw(unstable client ssh) ],
       attributes => {
          hostname => [ qw(hostname) ],
          port => [ qw(integer) ],
@@ -33,10 +31,9 @@ sub brik_properties {
          use_publickey => 1,
       },
       commands => {
-         install => [ ], # Inherited
          connect => [ qw(hostname|OPTIONAL port|OPTIONAL username|OPTIONAL) ],
          cat => [ qw(file) ],
-         execute => [ qw(command) ],
+         exec => [ qw(command) ],
          read => [ ],
          read_line => [ ],
          read_line_all => [ ],
@@ -49,9 +46,6 @@ sub brik_properties {
          'Net::SSH2' => [ ],
          'Metabrik::String::Password' => [ ],
       },
-      need_packages => {
-         'ubuntu' => [ qw(libssh2-1-dev) ],
-      },
    };
 }
 
@@ -67,12 +61,9 @@ sub connect {
    $port ||= $self->port;
    $username ||= $self->username;
    $password ||= $self->password;
-   $self->brik_help_run_undef_arg('connect', $hostname) or return;
-   $self->brik_help_run_undef_arg('connect', $port) or return;
-   $self->brik_help_run_undef_arg('connect', $username) or return;
-
    my $publickey = $self->publickey;
    my $privatekey = $self->privatekey;
+
    if ($self->use_publickey && ! $publickey) {
       return $self->log->error($self->brik_help_set('publickey'));
    }
@@ -134,23 +125,27 @@ sub disconnect {
    return $r;
 }
 
-sub execute {
+sub exec {
    my $self = shift;
    my ($cmd) = @_;
 
    my $ssh2 = $self->ssh2;
-   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
-   $self->brik_help_run_undef_arg('execute', $cmd) or return;
+   if (! defined($ssh2)) {
+      return $self->log->error($self->brik_help_run('connect'));
+   }
+   if (! defined($cmd)) {
+      return $self->log->error($self->brik_help_run('exec'));
+   }
 
-   $self->debug && $self->log->debug("execute: cmd [$cmd]");
+   $self->debug && $self->log->debug("exec: cmd [$cmd]");
 
    my $channel = $ssh2->channel;
    if (! defined($channel)) {
-      return $self->log->error("execute: channel creation error");
+      return $self->log->error("exec: channel creation error");
    }
 
    $channel->exec($cmd)
-      or return $self->log->error("execute: can't execute command [$cmd]: $!");
+      or return $self->log->error("exec: can't execute command [$cmd]: $!");
 
    return $self->_channel($channel);
 }
@@ -159,7 +154,9 @@ sub read_line {
    my $self = shift;
 
    my $ssh2 = $self->ssh2;
-   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   if (! defined($ssh2)) {
+      return $self->log->error($self->brik_help_run('connect'));
+   }
 
    my $channel = $self->_channel;
    if (! defined($channel)) {
@@ -193,7 +190,9 @@ sub read_line_all {
    my $self = shift;
 
    my $ssh2 = $self->ssh2;
-   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   if (! defined($ssh2)) {
+      return $self->log->error($self->brik_help_run('connect'));
+   }
 
    my $channel = $self->_channel;
    if (! defined($channel)) {
@@ -214,7 +213,9 @@ sub read {
    my $self = shift;
 
    my $ssh2 = $self->ssh2;
-   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
+   if (! defined($ssh2)) {
+      return $self->log->error($self->brik_help_run('connect'));
+   }
 
    my $channel = $self->_channel;
    if (! defined($channel)) {
@@ -248,7 +249,10 @@ sub listfiles {
    my $self = shift;
    my ($glob) = @_;
 
-   my $channel = $self->execute("ls $glob 2> /dev/null") or return;
+   my $channel = $self->exec("ls $glob 2> /dev/null");
+   if (! defined($channel)) {
+      return $self->log->error("listfiles: exec error");
+   }
 
    my $read = $self->read;
    if (! defined($read)) {
@@ -264,11 +268,18 @@ sub cat {
    my $self = shift;
    my ($file) = @_;
 
-   my $ssh2 = $self->ssh2;
-   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
-   $self->brik_help_run_undef_arg('cat', $file) or return;
+   if (! defined($self->ssh2)) {
+      return $self->log->error($self->brik_help_run('connect'));
+   }
 
-   my $channel = $self->execute('cat '.$file) or return;
+   if (! defined($file)) {
+      return $self->log->error($self->brik_help_run('cat'));
+   }
+
+   my $channel = $self->exec('cat '.$file);
+   if (! defined($channel)) {
+      return $self->log->error("cat: channel for file [$file]");
+   }
 
    return $self->_channel($channel);
 }
@@ -277,9 +288,15 @@ sub load {
    my $self = shift;
    my ($file) = @_;
 
+   if (! defined($self->ssh2)) {
+      return $self->log->error($self->brik_help_run('connect'));
+   }
+
+   if (! defined($file)) {
+      return $self->log->error($self->brik_help_run('load'));
+   }
+
    my $ssh2 = $self->ssh2;
-   $self->brik_help_run_undef_arg('connect', $ssh2) or return;
-   $self->brik_help_run_undef_arg('load', $file) or return;
 
    my $io = IO::Scalar->new;
 
@@ -319,7 +336,7 @@ Metabrik::Client::Ssh - client::ssh Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
