@@ -1,5 +1,5 @@
 #
-# $Id: Udp.pm,v 67526b1fc540 2015/10/19 15:35:38 gomor $
+# $Id: Udp.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
 #
 # client::udp Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Client::Tcp);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 67526b1fc540 $',
+      revision => '$Revision: 887d85a7f604 $',
       tags => [ qw(unstable client udp socket netcat) ],
       attributes => {
          host => [ qw(host) ],
@@ -28,8 +28,8 @@ sub brik_properties {
       },
       commands => {
          connect => [ qw(host|OPTIONAL port|OPTIONAL) ],
-         read => [ qw(size) ],
-         readall => [ ],
+         read => [ ],
+         read_size => [ qw(size) ],
          write => [ qw($data) ],
          disconnect => [ ],
          is_connected => [ ],
