@@ -1,5 +1,5 @@
 #
-# $Id: Www.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Www.pm,v 443db6fb6411 2015/11/21 13:37:41 gomor $
 #
 # client::www Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
+      revision => '$Revision: 443db6fb6411 $',
       tags => [ qw(unstable browser http client www javascript screenshot) ],
       attributes => {
          uri => [ qw(uri) ],
@@ -20,12 +20,17 @@ sub brik_properties {
          ignore_content => [ qw(0|1) ],
          user_agent => [ qw(user_agent) ],
          ssl_verify => [ qw(0|1) ],
+         datadir => [ qw(datadir) ],
+         timeout => [ qw(0|1) ],
+         rtimeout => [ qw(timeout) ],
          _client => [ qw(object|INTERNAL) ],
          _last => [ qw(object|INTERNAL) ],
       },
       attributes_default => {
          ssl_verify => 0,
          ignore_content => 0,
+         timeout => 0,
+         rtimeout => 10,
       },
       commands => {
          create_user_agent => [ ],
@@ -44,21 +49,27 @@ sub brik_properties {
          forms => [ ],
          links => [ ],
          trace_redirect => [ qw(uri|OPTIONAL) ],
-         screenshot => [ qw(uri output_file) ],
+         screenshot => [ qw(uri output) ],
          eval_javascript => [ qw(js uri|OPTIONAL) ],
          info => [ ],
+         mirror => [ qw(url|$url_list output|OPTIONAL datadir|OPTIONAL) ],
       },
       require_modules => {
+         'Progress::Any::Output' => [ ],
+         'Progress::Any::Output::TermProgressBarColor' => [ ],
          'Net::SSL' => [ ],
          'Data::Dumper' => [ ],
          'LWP::UserAgent' => [ ],
+         'LWP::UserAgent::ProgressAny' => [ ],
          'HTTP::Request' => [ ],
          'WWW::Mechanize' => [ ],
-         'WWW::Mechanize::PhantomJS' => [ ],
          'Metabrik::File::Write' => [ ],
          'Metabrik::Client::Ssl' => [ ],
       },
-      require_binaries => {
+      optional_modules => {
+         'WWW::Mechanize::PhantomJS' => [ ],
+      },
+      optional_binaries => {
          'phantomjs' => [ ],
       },
    };
@@ -78,7 +89,7 @@ sub create_user_agent {
       # IO::Socket::SSL, Net::SSL, Net::SSLeay, Net::HTTPS, AnyEvent::TLS just sucks.
       # So we have to perform a first TCP connexion to verify cert, then a second 
       # One to actually negatiate an unverified session.
-      my $cs = Metabrik::Client::Ssl->new_from_brik($self) or return;
+      my $cs = Metabrik::Client::Ssl->new_from_brik_init($self) or return;
       my $verified = $cs->verify_server($uri);
       if (! defined($verified)) {
          return;
@@ -92,7 +103,7 @@ sub create_user_agent {
 
    my $mech = WWW::Mechanize->new(
       autocheck => 0,  # Do not throw on error by checking HTTP code. Let us do it.
-      timeout => $self->global->rtimeout,
+      timeout => $self->rtimeout,
       ssl_opts => {
          verify_hostname => 0,
       },
@@ -136,6 +147,8 @@ sub _method {
       return $self->log->error($self->brik_help_run($method));
    }
 
+   $self->timeout(0);
+
    $username ||= $self->username;
    $password ||= $self->password;
    my $client = $self->_client;
@@ -161,6 +174,9 @@ sub _method {
    };
    if ($@) {
       chomp($@);
+      if ($@ =~ /read timeout/i) {
+         $self->timeout(1);
+      }
       return $self->log->error("$method: unable to $method uri [$uri]: $@");
    }
 
@@ -360,7 +376,7 @@ sub trace_redirect {
    }
 
    my $lwp = LWP::UserAgent->new(%args);
-   $lwp->timeout($self->global->rtimeout);
+   $lwp->timeout($self->rtimeout);
    $lwp->agent('Mozilla/5.0');
    $lwp->max_redirect(0);
    $lwp->env_proxy;
@@ -407,41 +423,61 @@ sub screenshot {
    my $self = shift;
    my ($uri, $output) = @_;
 
-   my $mech = WWW::Mechanize::PhantomJS->new
-      or return $self->log->error("screenshot: PhantomJS failed");
-   $mech->get($uri)
-      or return $self->log->error("screenshot: get uri [$uri] failed");
+   if (! defined($uri) || ! defined($output)) {
+      return $self->log->error($self->brik_help_run('screenshot'));
+   }
 
-   my $data = $mech->content_as_png
-      or return $self->log->error("screenshot: content_as_png failed");
+   if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
+   &&  $self->brik_has_binary('phantomjs')) {
+      my $mech = WWW::Mechanize::PhantomJS->new
+         or return $self->log->error("screenshot: PhantomJS failed");
 
-   my $write = Metabrik::File::Write->new_from_brik($self) or return;
-   $write->encoding('ascii');
-   $write->overwrite(1);
-   $write->append(0);
+      my $get = $mech->get($uri)
+         or return $self->log->error("screenshot: get uri [$uri] failed");
 
-   $write->open($output) or return $self->log->error("screenshot: open failed");
-   $write->write($data) or return $self->log->error("screenshot: write failed");
-   $write->close;
+      my $data = $mech->content_as_png
+         or return $self->log->error("screenshot: content_as_png failed");
 
-   return $output;
+      my $write = Metabrik::File::Write->new_from_brik_init($self) or return;
+      $write->encoding('ascii');
+      $write->overwrite(1);
+      $write->append(0);
+
+      $write->open($output) or return $self->log->error("screenshot: open failed");
+      $write->write($data) or return $self->log->error("screenshot: write failed");
+      $write->close;
+
+      return $output;
+   }
+
+   return $self->log->error("screenshot: optional module [WWW::Mechanize::PhantomJS] and optional binary [phantomjs] are not available");
 }
 
 sub eval_javascript {
    my $self = shift;
    my ($js, $uri) = @_;
 
-   # Perl module Wight may also be an option.
-
-   my $mech = WWW::Mechanize::PhantomJS->new
-      or return $self->log->error("eval_javascript: PhantomJS failed");
-
-   if ($uri) {
-      $mech->get($uri)
-         or return $self->log->error("eval_javascript: get uri [$uri] failed");
+   if (! defined($js) || ! defined($uri)) {
+      return $self->log->error($self->brik_help_run('eval_javascript'));
    }
 
-   return $mech->eval_in_page($js);
+   # Perl module Wight may also be an option.
+
+   if ($self->brik_has_module('WWW::Mechanize::PhantomJS')
+   &&  $self->brik_has_binary('phantomjs')) {
+      my $mech = WWW::Mechanize::PhantomJS->new
+         or return $self->log->error("eval_javascript: PhantomJS failed");
+
+      my $get = $mech->get($uri)
+         or return $self->log->error("eval_javascript: get uri [$uri] failed");
+      if (! $get->is_success) {
+         return $self->log->error("eval_javascript: error from GET: [".$get->status_line."]");
+      }
+
+      return $mech->eval_in_page($js);
+   }
+
+   return $self->log->error("eval_javascript: optional module [WWW::Mechanize::PhantomJS] and optional binary [phantomjs] are not available");
 }
 
 sub info {
@@ -518,6 +554,56 @@ sub info {
    return $mech;
 }
 
+sub mirror {
+   my $self = shift;
+   my ($url, $output, $datadir) = @_;
+
+   if (! defined($url) || ! defined($output)) {
+      return $self->log->error($self->brik_help_run('mirror'));
+   }
+
+   $datadir ||= $self->datadir;
+
+   my @files = ();
+   if (ref($url) eq 'ARRAY') {
+      for my $this (@$url) {
+         my $file = $self->mirror($this, $output) or next;
+         push @files, @$file;
+      }
+   }
+   else {
+      if ($url !~ /^https?:\/\// && $url !~ /^ftp:\/\//) {
+         return $self->log->error("mirror: invalid URL [$url]");
+      }
+
+      $self->debug && $self->log->debug("mirror: url[$url] output[$output]");
+
+      my $mech = $self->create_user_agent or return;
+      LWP::UserAgent::ProgressAny::__add_handlers($mech);
+      Progress::Any::Output->set("TermProgressBarColor");
+
+      my $rc;
+      eval {
+         $rc = $mech->mirror($url, $datadir.'/'.$output);
+      };
+      if ($@) {
+         chomp($@);
+         return $self->log->error("mirror: mirroring URL [$url] to local file [$output] failed: $@");
+      }
+      my $code = $rc->code;
+      if ($rc->code == 200) {
+         my $file = $datadir.'/'.$output;
+         push @files, $file;
+         $self->log->info("mirror: downloading URL [$url] to local file [$file] done");
+      }
+      elsif ($rc->code == 304) { # Not modified
+         $self->log->info("mirror: file [$output] not modified since last check");
+      }
+   }
+
+   return \@files;
+}
+
 1;
 
 __END__
