@@ -1,5 +1,5 @@
 #
-# $Id: Elasticsearch.pm,v f86a021f7e5f 2015/01/24 17:03:49 gomor $
+# $Id: Elasticsearch.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
 #
 # database::elasticsearch Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f86a021f7e5f $',
+      revision => '$Revision: 508610fe2b1a $',
       tags => [ qw(unstable elasticsearch elk) ],
       attributes => {
          nodes => [ qw(node_list) ],
@@ -269,7 +269,7 @@ sub www_search {
          next;
       }
 
-      my $body = $get->{body};
+      my $body = $get->{content};
       my $string_json = Metabrik::String::Json->new_from_brik($self) or return;
       my $decoded = $string_json->decode($body)
          or return $self->log->error("www_search: decode failed");
