@@ -1,5 +1,5 @@
 #
-# $Id: Compress.pm,v 5be2a244bacc 2015/03/26 07:06:31 gomor $
+# $Id: Compress.pm,v 4f8333db5069 2015/11/19 07:36:05 gomor $
 #
 # file::zip brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 5be2a244bacc $',
+      revision => '$Revision: 4f8333db5069 $',
       tags => [ qw(unstable compress unzip gunzip uncompress) ],
       attributes => {
          datadir => [ qw(directory) ],
@@ -20,7 +20,8 @@ sub brik_properties {
       },
       commands => {
          unzip => [ qw(input|OPTIONAL datadir|OPTIONAL) ],
-         gunzip => [ qw(input|OPTIONAL output|OPTIONAL) ],
+         gunzip => [ qw(input|OPTIONAL output|OPTIONAL datadir|OPTIONAL) ],
+         uncompress => [ qw(input|OPTIONAL output|OPTIONAL datadir|OPTIONAL) ],
       },
       require_modules => {
          'Metabrik::File::Write' => [ ],
@@ -38,7 +39,7 @@ sub unzip {
 
    $input ||= $self->input;
    if (! defined($input)) {
-      return $self->log->error($self->brik_help_set('input'));
+      return $self->log->error($self->brik_help_run('unzip'));
    }
 
    $datadir ||= $self->datadir;
@@ -52,11 +53,11 @@ sub unzip {
 
 sub gunzip {
    my $self = shift;
-   my ($input, $output) = @_;
+   my ($input, $output, $datadir) = @_;
 
    $input ||= $self->input;
    if (! defined($input)) {
-      return $self->log->error($self->brik_help_set('input'));
+      return $self->log->error($self->brik_help_run('gunzip'));
    }
 
    $output ||= $self->output;
@@ -65,6 +66,8 @@ sub gunzip {
       ($output = $input) =~ s/.gz$//;
    }
 
+   $datadir ||= $self->datadir;
+
    my $gz = Compress::Zlib::gzopen($input, "rb");
    if (! $gz) {
       return $self->log->error("gunzip: gzopen file [$input]: [$Compress::Zlib::gzerrno]");
@@ -75,7 +78,7 @@ sub gunzip {
    $fw->encoding('ascii');
    $fw->overwrite(1);
 
-   my $fd = $fw->open($output);
+   my $fd = $fw->open($datadir.'/'.$output);
    if (! defined($fd)) {
       return $self->log->error("gunzip: open failed");
    }
@@ -98,6 +101,27 @@ sub gunzip {
    return $no_error;
 }
 
+sub uncompress {
+   my $self = shift;
+   my ($input, $output, $datadir) = @_;
+
+   $input ||= $self->input;
+   if (! defined($input)) {
+      return $self->log->error($self->brik_help_run('uncompress'));
+   }
+
+   $datadir ||= $self->datadir;
+
+   if ($input =~ /\.gz$/) {
+      return $self->gunzip($input, $output, $datadir);
+   }
+   elsif ($input =~ /\.zip$/) {
+      return $self->unzip($input, $datadir);
+   }
+
+   return $self->log->error("uncompress: don't know how to uncompress file [$input]");
+}
+
 1;
 
 __END__
