@@ -1,5 +1,5 @@
 #
-# $Id: Dump.pm,v 981ef846f9ef 2015/03/26 06:11:36 gomor $
+# $Id: Dump.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
 #
 # file::dump Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Write);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 981ef846f9ef $',
+      revision => '$Revision: 887d85a7f604 $',
       tags => [ qw(unstable file dump read write) ],
       attributes => {
          input => [ qw(file) ],
@@ -41,15 +41,15 @@ sub read {
       return $self->log->error($self->brik_help_run('read'));
    }
 
-   my $read = Metabrik::File::Read->new_from_brik($self) or return;
-   $read->input($input);
-   $read->encoding($self->encoding);
-   $read->as_array(1);
-   $read->strip_crlf(1);
+   my $fr = Metabrik::File::Read->new_from_brik_init($self) or return;
+   $fr->input($input);
+   $fr->encoding($self->encoding);
+   $fr->as_array(1);
+   $fr->strip_crlf(1);
 
-   $read->open or return $self->log->error("read: open failed");
-   my $data = $read->readall or return $self->log->error("read: read failed");
-   $read->close;
+   $fr->open or return $self->log->error("read: open failed");
+   my $data = $fr->read or return $self->log->error("read: read failed");
+   $fr->close;
 
    my @vars = ();
    my $buf = '';
