@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v 297f479a9ee8 2015/02/11 06:55:12 gomor $
+# $Id: Read.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
 #
 # file::read Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 297f479a9ee8 $',
+      revision => '$Revision: 887d85a7f604 $',
       tags => [ qw(unstable file) ],
       attributes => {
          input => [ qw(file) ],
@@ -31,9 +31,10 @@ sub brik_properties {
       commands => {
          open => [ qw(file|OPTIONAL) ],
          close => [ ],
-         readall => [ ],
+         read => [ ],
          read_until_blank_line => [ ],
          read_line => [ qw(count|OPTIONAL) ],
+         is_eof => [ ],
       },
    };
 }
@@ -79,12 +80,13 @@ sub close {
 
    if (defined($self->fd)) {
       close($self->fd);
+      $self->eof(0);
    }
 
    return 1;
 }
 
-sub readall {
+sub read {
    my $self = shift;
 
    my $fd = $self->fd;
@@ -206,6 +208,12 @@ sub read_line {
    return;
 }
 
+sub is_eof {
+   my $self = shift;
+
+   return $self->eof;
+}
+
 1;
 
 __END__
