@@ -1,5 +1,5 @@
 #
-# $Id: Xml.pm,v 14a5b315905e 2015/01/08 07:00:53 gomor $
+# $Id: Xml.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
 #
 # file::xml Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Read);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 14a5b315905e $',
+      revision => '$Revision: 887d85a7f604 $',
       tags => [ qw(unstable xml file) ],
       attributes => {
          input => [ qw(file) ],
@@ -55,7 +55,7 @@ sub read {
    }
 
    $self->open($input) or return $self->log->error("read: open failed");
-   my $data = $self->readall or return $self->log->error("read: readall failed");
+   my $data = $self->read or return $self->log->error("read: read failed");
    $self->close;
 
    my $xml = Metabrik::String::Xml->new_from_brik($self) or return;
