@@ -1,5 +1,5 @@
 #
-# $Id: Null.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Null.pm,v 02964d3ea8ac 2015/11/10 08:41:24 gomor $
 #
 # log::null Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: 02964d3ea8ac $',
+      tags => [ qw(log null) ],
       attributes => {
          level => [ qw(0|1|2|3) ],
       },
@@ -107,7 +105,7 @@ Metabrik::Log::Null - log::null Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
