@@ -1,5 +1,5 @@
 #
-# $Id: Oui.pm,v 616178e78f07 2015/10/17 16:55:47 gomor $
+# $Id: Oui.pm,v 4f8333db5069 2015/11/19 07:36:05 gomor $
 #
 # lookup::oui Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::File::Text);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 616178e78f07 $',
+      revision => '$Revision: 4f8333db5069 $',
       tags => [ qw(unstable lookup oui ieee) ],
       attributes => {
          datadir => [ qw(datadir) ],
@@ -29,7 +29,7 @@ sub brik_properties {
          all => [ ],
       },
       require_modules => {
-         'Metabrik::File::Fetch' => [ ],
+         'Metabrik::Client::Www' => [ ],
       },
    };
 }
@@ -38,17 +38,17 @@ sub update {
    my $self = shift;
    my ($output) = @_;
 
-   my $url = 'http://standards-oui.ieee.org/oui.txt';
-   my ($file) = $self->input;
+   my $input = $self->input;
+   my $datadir = $self->datadir;
+   $output ||= $input;
 
    # XXX: should also check for generic attribution:
    # http://www.iana.org/assignments/ethernet-numbers/ethernet-numbers-2.csv
 
-   $output ||= $self->datadir.'/'.$file;
+   my $url = 'http://standards-oui.ieee.org/oui.txt';
 
-   my $ff = Metabrik::File::Fetch->new_from_brik_init($self) or return;
-   $ff->get($url, $output)
-      or return $self->log->error("update: get failed");
+   my $cw = Metabrik::Client::Www->new_from_brik_init($self) or return;
+   $cw->mirror($url, $output, $datadir) or return;
 
    return $output;
 }
