@@ -1,5 +1,5 @@
 #
-# $Id: Arp.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Arp.pm,v 4a548f1412b7 2015/11/22 16:44:04 gomor $
 #
 # network::arp Brik
 #
@@ -11,51 +11,55 @@ use base qw(Metabrik::Network::Frame);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
+      revision => '$Revision: 4a548f1412b7 $',
       tags => [ qw(unstable arp cache poison eui64 discover scan) ],
       attributes => {
          try => [ qw(try_count) ],
-         timeout => [ qw(timeout_seconds) ],
+         rtimeout => [ qw(timeout_seconds) ],
          max_read => [ qw(max_read_packet) ],
          max_runtime => [ qw(max_runtime) ],
-         _dnet => [ qw(Net::Libdnet::Arp) ],
+         device => [ qw(device) ],
+         _pidfile => [ qw(INTERNAL) ],
       },
       attributes_default => {
          try => 2,
-         timeout => 2,
+         rtimeout => 2,
       },
       commands => {
          cache => [ ],
-         half_poison => [ ],
-         full_poison => [ ],
+         half_poison => [ qw(gateway victim|OPTIONAL device|OPTIONAL) ],
+         full_poison => [ qw(gateway victim|OPTIONAL device|OPTIONAL) ],
          mac2eui64 => [ qw(mac_address) ],
-         scan => [ qw(subnet|OPTIONAL) ],
-         get_ipv4_neighbors => [ qw(subnet|OPTIONAL) ],
-         get_ipv6_neighbors => [ qw(subnet|OPTIONAL) ],
-         get_mac_neighbors => [ qw(subnet|OPTIONAL) ],
+         scan => [ qw(subnet|OPTIONAL device[OPTIONAL) ],
+         get_ipv4_neighbors => [ qw(subnet|OPTIONAL device|OPTIONAL) ],
+         get_ipv6_neighbors => [ qw(subnet|OPTIONAL device|OPTIONAL) ],
+         get_mac_neighbors => [ qw(subnet|OPTIONAL device|OPTIONAL) ],
+         stop_poison => [ ],
       },
       require_modules => {
-         'Metabrik::Network::Arp' => [ ],
-         'Metabrik::Network::Write' => [ ],
-         'Metabrik::Network::Read' => [ ],
-         'Metabrik::Network::Address' => [ ],
          'Net::Frame::Layer::ARP' => [ ],
          'Net::Libdnet::Arp' => [ ],
+         'Metabrik::Network::Address' => [ ],
+         'Metabrik::Network::Arp' => [ ],
+         'Metabrik::Network::Read' => [ ],
+         'Metabrik::Network::Write' => [ ],
+         'Metabrik::Shell::Command' => [ ],
+         'Metabrik::System::Process' => [ ],
+      },
+      optional_binaries => {
+         'arpspoof' => [ ],
       },
    };
 }
 
-sub brik_init {
+sub brik_use_properties {
    my $self = shift;
 
-   my $dnet = Net::Libdnet::Arp->new;
-   if (! defined($dnet)) {
-      return $self->log->error("brik_init: unable to create Net::Libdnet::Arp object");
-   }
-
-   $self->_dnet($dnet);
-
-   return $self->SUPER::brik_init(@_);
+   return {
+      attributes_default => {
+         device => $self->global->device,
+      },
+   };
 }
 
 sub _loop {
@@ -70,24 +74,64 @@ sub _loop {
 sub cache {
    my $self = shift;
 
+   my $dnet = Net::Libdnet::Arp->new;
+
    my %data = ();
-   $self->_dnet->loop(\&_loop, \%data);
+   $dnet->loop(\&_loop, \%data);
 
    return \%data;
 }
 
 sub half_poison {
    my $self = shift;
+   my ($gateway, $victim, $device) = @_;
 
-   $self->log->info("TODO");
+   if (! $self->brik_has_binary("arpspoof")) {
+      return $self->log->error("half_poison: you have to install dsniff package");
+   }
+
+   $device ||= $self->device;
+   if (! defined($gateway)) {
+      return $self->log->error($self->brik_help_run('half_poison'))
+   }
+
+   my $cmd = "arpspoof -i $device -c both";
+   $cmd .= " -t $victim" if defined($victim);  # Or default to all LAN hosts
+   $cmd .= " $gateway";
+
+   my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
+   my $sp = Metabrik::System::Process->new_from_brik_init($self) or return;
+   my $pidfile = $sp->daemonize(sub { $sc->system($cmd) });
+   $self->_pidfile($pidfile);
+
+   $self->log->info("half_poison: daemonized to pidfile[$pidfile]");
 
    return 1;
 }
 
 sub full_poison {
    my $self = shift;
+   my ($gateway, $victim, $device) = @_;
 
-   $self->log->info("TODO");
+   if (! $self->brik_has_binary("arpspoof")) {
+      return $self->log->error("full_poison: you have to install dsniff package");
+   }
+
+   $device ||= $self->device;
+   if (! defined($gateway)) {
+      return $self->log->error($self->brik_help_run('full_poison'))
+   }
+
+   my $cmd = "arpspoof -i $device -c both -r";
+   $cmd .= " -t $victim" if defined($victim);  # Or default to all LAN hosts
+   $cmd .= " $gateway";
+
+   my $sc = Metabrik::Shell::Command->new_from_brik_init($self) or return;
+   my $sp = Metabrik::System::Process->new_from_brik_init($self) or return;
+   my $pidfile = $sp->daemonize(sub { $sc->system($cmd) });
+   $self->_pidfile($pidfile);
+
+   $self->log->info("full_poison: daemonized to pidfile[$pidfile]");
 
    return 1;
 }
@@ -127,15 +171,13 @@ sub _get_arp_frame {
 
 sub scan {
    my $self = shift;
-   my ($subnet) = @_;
+   my ($subnet, $device) = @_;
 
    if ($< != 0) {
       return $self->log->error("scan: must be root to run");
    }
 
-   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
-
-   my $interface = $self->device_info;
+   my $interface = $self->get_device_info($device) or return;
 
    $subnet ||= $interface->{subnet4};
    if (! defined($subnet)) {
@@ -145,8 +187,9 @@ sub scan {
    my $arp_cache = $self->cache
       or return $self->log->error("scan: cache failed");
 
-   my $ip_list = $na->ipv4_list($subnet)
-      or return $self->log->error("scan: ipv4_list failed");
+   my $na = Metabrik::Network::Address->new_from_brik_init($self) or return;
+
+   my $ip_list = $na->ipv4_list($subnet) or return;
 
    my $reply_cache = {};
    my $local_arp_cache = {};
@@ -154,9 +197,10 @@ sub scan {
 
    for my $ip (@$ip_list) {
       # We scan ARP for everyone but our own IP
-      next if $ip eq $interface->{ipv4};
+      if (exists($interface->{ipv4}) && $ip eq $interface->{ipv4}) {
+         next;
+      }
 
-      # XXX: move to network::arp so there is one place for ARP cache handling
       my $mac;
       if (exists($local_arp_cache->{$ip})) {
          $mac = $local_arp_cache->{$ip};
@@ -175,16 +219,14 @@ sub scan {
 
    my $nw = Metabrik::Network::Write->new_from_brik_init($self) or return;
 
-   my $write = $nw->open(2, $self->device)
-      or return $self->log->error("scan: open failed");
+   my $write = $nw->open(2, $interface->{device}) or return;
 
    my $nr = Metabrik::Network::Read->new_from_brik_init($self) or return;
-   $nr->rtimeout($self->timeout);
+   $nr->rtimeout($self->rtimeout);
    $nr->max_read($self->max_read || 0);
 
    my $filter = 'arp and src net '.$subnet.' and dst host '.$interface->{ipv4};
-   my $read = $nr->open(2, $self->device, $filter)
-      or return $self->log->error("scan: open failed");
+   my $read = $nr->open(2, $interface->{device}, $filter) or return;
 
    # We will send frames 3 times max
    my $try = $self->try;
@@ -200,7 +242,7 @@ sub scan {
       }
 
       # Then we wait for all replies until a timeout occurs
-      my $h_list = $nr->next_until_timeout;
+      my $h_list = $nr->read_until_timeout;
       for my $h (@$h_list) {
          my $r = $self->from_read($h);
          #$self->log->verbose("scan: read next returned some stuff".$r->print);
@@ -237,6 +279,16 @@ sub scan {
       $results{by_ipv6}{$ip6} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
    }
 
+   # And complete with the cache table
+   for (keys %{$arp_cache->{mac}}) {
+      my $mac = $_;
+      my $ip4 = $arp_cache->{mac}{$_};
+      my $ip6 = $self->mac2eui64($mac);
+      $results{by_mac}{$mac} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
+      $results{by_ipv4}{$ip4} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
+      $results{by_ipv6}{$ip6} = { ipv6 => $ip6, mac => $mac, ipv4 => $ip4 };
+   }
+
    return \%results;
 }
 
@@ -279,6 +331,27 @@ sub get_mac_neighbors {
    return $mac;
 }
 
+sub stop_poison {
+   my $self = shift;
+
+   my $pidfile = $self->_pidfile;
+   if (defined($pidfile)) {
+      my $sp = Metabrik::System::Process->new_from_brik_init($self) or return;
+      $sp->force_kill(1);
+      $sp->kill_from_pidfile($pidfile);
+      $self->log->verbose("stop_poison: killing arpspoof process");
+      $self->_pidfile(undef);
+   }
+
+   return 1;
+}
+
+sub brik_fini {
+   my $self = shift;
+
+   return $self->stop_poison;
+}
+
 1;
 
 __END__
