@@ -1,5 +1,5 @@
 #
-# $Id: Device.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Device.pm,v 443db6fb6411 2015/11/21 13:37:41 gomor $
 #
 # network::device Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
+      revision => '$Revision: 443db6fb6411 $',
       tags => [ qw(unstable network device interface) ],
       attributes => {
          'enable_warnings' => [ qw(0|1) ],
@@ -159,14 +159,15 @@ sub show {
    } 
 
    for my $this (@$devices) {
+      $self->debug && $self->log->debug("show: found device [$this]");
       my $device = $self->get($this);
-      if (! defined($device)) {
+      if (! defined($device) || ! exists($device->{device})) {
          $self->enable_warnings
             && $self->log->warning("show: get failed for device [$this]");
          next;
       }
 
-      printf("device: %s\nipv4: %s  subnet4: %s\nipv6: %s  subnet6: %s\n",
+      printf("device: %s\nipv4: %s  subnet4: %s\nipv6: %s  subnet6: %s\n\n",
          $device->{device},
          $device->{ipv4},
          $device->{subnet4},
