@@ -1,5 +1,5 @@
 #
-# $Id: Frame.pm,v 4b17ceef135b 2015/10/17 09:10:37 gomor $
+# $Id: Frame.pm,v 4a548f1412b7 2015/11/22 16:44:04 gomor $
 #
 # network::frame Brik
 #
@@ -11,15 +11,17 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 4b17ceef135b $',
+      revision => '$Revision: 4a548f1412b7 $',
       tags => [ qw(unstable network frame packet ip tcp udp icmp eth ethernet arp) ],
       attributes => {
          device => [ qw(device) ],
          device_info => [ qw(device_info_hash) ],
       },
       commands => {
-         update_device_info => [ ],
-         from_read => [ qw(frame) ],
+         get_device_info => [ qw(device|OPTIONAL) ],
+         update_device_info => [ qw(device|OPTIONAL) ],
+         from_read => [ qw(frame|$frame_list) ],
+         to_read => [ qw(simple|$simple_list) ],
          from_hexa => [ qw(hexa first_layer|OPTIONAL) ],
          from_raw => [ qw(raw first_layer|OPTIONAL) ],
          show => [ ],
@@ -27,11 +29,13 @@ sub brik_properties {
          frame => [ qw(layers_array) ],
          arp => [ qw(destination_ipv4_address|OPTIONAL destination_mac|OPTIONAL) ],
          eth => [ qw(destination_mac|OPTIONAL type|OPTIONAL) ],
-         ipv4 => [ qw(destination_ipv4_address|OPTIONAL protocol|OPTIONAL) ],
-         tcp => [ qw(destination_port|OPTIONAL source_port|OPTIONAL flags|OPTIONAL) ],
-         udp => [ qw(destination_port|OPTIONAL source_port|OPTIONAL payload|OPTIONAL) ],
+         ipv4 => [ qw(destination_ipv4_address protocol|OPTIONAL source_ipv4_address|OPTIONAL) ],
+         tcp => [ qw(destination_port source_port|OPTIONAL flags|OPTIONAL) ],
+         udp => [ qw(destination_port source_port|OPTIONAL payload|OPTIONAL) ],
          icmpv4 => [ ],
          echo_icmpv4 => [ ],
+         is_read => [ qw(data) ],
+         is_simple => [ qw(data) ],
       },
       require_modules => {
          'Net::Frame::Simple' => [ ],
@@ -68,7 +72,7 @@ sub brik_init {
    return $self->SUPER::brik_init(@_);
 }
 
-sub update_device_info {
+sub get_device_info {
    my $self = shift;
    my ($device) = @_;
 
@@ -76,33 +80,106 @@ sub update_device_info {
 
    my $nd = Metabrik::Network::Device->new_from_brik_init($self) or return;
 
-   my $device_info = $nd->get($device)
-      or return $self->log->error("update_device_info: get failed");
+   my $device_info = $nd->get($device) or return;
 
-   $self->log->verbose("update_device_info: updating from device [$device]");
+   $self->log->verbose("get_device_info: got info from device [$device]");
 
-   return $self->device_info($device_info);
+   return $device_info;
+}
+
+sub update_device_info {
+   my $self = shift;
+   my ($device) = @_;
+
+   return $self->device_info($self->get_device_info($device));
 }
 
 sub from_read {
    my $self = shift;
-   my ($data) = @_;
+   my ($frames) = @_;
 
-   if (! defined($data)) {
+   if (! defined($frames)) {
       return $self->log->error($self->brik_help_run('from_read'));
    }
 
-   if (ref($data) ne 'HASH') {
-      return $self->log->error("from_read: data must be a HASHREF");
+   # We accept a one frame Argument...
+   if (ref($frames) eq 'HASH') {
+      if (! exists($frames->{raw})
+      ||  ! exists($frames->{firstLayer})
+      ||  ! exists($frames->{timestamp})) {
+         return $self->log->error("from_read: frames Argument is not an array of valid next HASHREFs");
+      }
+      else {
+         return Net::Frame::Simple->newFromDump($frames);
+      }
    }
 
-   if (! exists($data->{raw})
-   ||  ! exists($data->{firstLayer})
-   ||  ! exists($data->{timestamp})) {
-      return $self->log->error("from_read: data must be come from network::read Brik");
+   # Or an ARRAY or frames
+   if (ref($frames) ne 'ARRAY') {
+      return $self->log->error("from_read: frames Argument must be an ARRAYREF");
+   }
+   if (@$frames <= 0) {
+      return $self->log->error("from_read: frames Argument is empty");
+   }
+   my $first = $frames->[0];
+   if (ref($first) ne 'HASH') {
+      return $self->log->error("from_read: frames Argument is not an array of next HASHREFs");
+   }
+   if (! exists($first->{raw})
+   ||  ! exists($first->{firstLayer})
+   ||  ! exists($first->{timestamp})) {
+      return $self->log->error("from_read: frames Argument is not an array of valid next HASHREFs");
    }
 
-   return Net::Frame::Simple->newFromDump($data);
+   my @simple = ();
+   for my $h (@$frames) {
+      my $simple = Net::Frame::Simple->newFromDump($h) or next;
+      push @simple, $simple;
+   }
+
+   return \@simple;
+}
+
+sub to_read {
+   my $self = shift;
+   my ($frame) = @_;
+
+   if (! defined($frame)) {
+      return $self->log->error($self->brik_help_run('to_read'));
+   }
+
+   my $ref = ref($frame);
+   my $first = $ref eq 'ARRAY' ? $frame->[0] : $frame;
+   if ($ref eq 'ARRAY') {
+      # We just check the first item in the list.
+      if (ref($first) eq 'Net::Frame::Simple') {
+         my @read = ();
+         for my $simple (@$frame) {
+            push @read, {
+               timestamp => $simple->timestamp,
+               firstLayer => $simple->firstLayer,
+               raw => $simple->raw,
+            };
+         }
+         return \@read;
+      }
+      else {
+         return $self->log->error("to_read: frame ARRAYREF must contain Net::Frame::Simple objects");
+      }
+   }
+   elsif ($ref eq 'Net::Frame::Simple') {
+      my $h = {
+         timestamp => $frame->timestamp,
+         firstLayer => $frame->firstLayer,
+         raw => $frame->raw,
+      };
+      return $h;
+   }
+   else {
+      return $self->log->error("to_read: frame Argument must be a Net::Frame::Simple object or an ARRAYREF");
+   }
+
+   return $self->log->error("to_read: unknown error occured");
 }
 
 sub from_hexa {
@@ -149,17 +226,17 @@ sub from_raw {
 
 sub show {
    my $self = shift;
-   my ($data) = @_;
+   my ($frame) = @_;
 
-   if (! defined($data)) {
+   if (! defined($frame)) {
       return $self->log->error($self->brik_help_run('show'));
    }
 
-   if (ref($data) ne 'Net::Frame::Simple') {
-      return $self->log->error("show: data must come from from_read Command");
+   if (ref($frame) ne 'Net::Frame::Simple') {
+      return $self->log->error("show: frame must be a Net::Frame::Simple object");
    }
 
-   my $str = $data->print;
+   my $str = $frame->print;
 
    print $str."\n";
 
@@ -224,15 +301,18 @@ sub eth {
 
 sub ipv4 {
    my $self = shift;
-   my ($dst, $protocol) = @_;
+   my ($dst, $protocol, $src) = @_;
+
+   $protocol ||= 6;  # TCP
+   if (! defined($dst)) {
+      return $self->log->error($self->brik_help_run('ipv4'));
+   }
 
    my $device_info = $self->device_info;
-
-   $dst ||= '127.0.0.1';
-   $protocol ||= 6;  # TCP
+   $src ||= $device_info->{ipv4};
 
    my $hdr = Net::Frame::Layer::IPv4->new(
-      src => $device_info->{ipv4},
+      src => $src,
       dst => $dst,
       protocol => $protocol,
    );
@@ -244,7 +324,10 @@ sub tcp {
    my $self = shift;
    my ($dst, $src, $flags) = @_;
 
-   $dst ||= 80;
+   if (! defined($dst)) {
+      return $self->log->error($self->brik_help_run('tcp'));
+   }
+
    $src ||= 1025;
    $flags ||= 0x02;   # SYN
 
@@ -259,7 +342,10 @@ sub udp {
    my $self = shift;
    my ($dst, $src, $payload) = @_;
 
-   $dst ||= 123;
+   if (! defined($dst)) {
+      return $self->log->error($self->brik_help_run('tcp'));
+   }
+
    $src ||= 1025;
    $payload ||= '';
 
@@ -310,6 +396,39 @@ sub frame {
    return $request;
 }
 
+sub is_read {
+   my $self = shift;
+   my ($data) = @_;
+
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('is_read'))
+   }
+
+   if (ref($data) eq 'HASH'
+   &&  exists($data->{raw})
+   &&  exists($data->{firstLayer})
+   &&  exists($data->{timestamp})) {
+      return 1;
+   }
+
+   return 0;
+}
+
+sub is_simple {
+   my $self = shift;
+   my ($data) = @_;
+
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('is_simple'))
+   }
+
+   if (ref($data) eq 'Net::Frame::Simple') {
+      return 1;
+   }
+
+   return 0;
+}
+
 1;
 
 __END__
