@@ -1,5 +1,5 @@
 #
-# $Id: Portscan.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Portscan.pm,v 4a548f1412b7 2015/11/22 16:44:04 gomor $
 #
 # network::portscan Brik
 #
@@ -11,9 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
+      revision => '$Revision: 4a548f1412b7 $',
       tags => [ qw(unstable portscan synscan tcpscan) ],
       attributes => {
+         device => [ qw(device) ],
          ports => [ qw(port_array) ],
          top10 => [ qw(top10_port_array) ],
          top100 => [ qw(top100_port_array) ],
@@ -134,6 +135,16 @@ sub brik_properties {
    };
 }
 
+sub brik_use_properties {
+   my $self = shift;
+
+   return {
+      attributes_default => {
+         device => $self->global->device,
+      },
+   };
+}
+
 sub tcp_syn {
    my $self = shift;
    my ($ip_list, $port_list, $pps) = @_;
@@ -170,8 +181,7 @@ sub tcp_syn {
    my $try = $self->try;
 
    my $nd = Metabrik::Network::Device->new_from_brik_init($self) or return;
-   my $get = $nd->get($self->global->device)
-      or return $self->log->error("tcp_syn: device failed");
+   my $get = $nd->get($self->device) or return;
 
    my $ip = $get->{ipv4};
    my $ip6 = $get->{ipv6};
@@ -241,7 +251,7 @@ sub tcp_syn {
    my %open;
    my %closed;
    while (! $nr->has_timeout) {
-      if (my $f = $nr->next) {
+      if (my $f = $nr->read_next) {
          my $s = Net::Frame::Simple->newFromDump($f);
          #printf STDERR "flags: 0x%02x\n", $s->ref->{TCP}->flags;
          if ($s->ref->{TCP}) {
