@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v 1d19720513f5 2015/03/08 11:41:04 gomor $
+# $Id: Read.pm,v 4a548f1412b7 2015/11/22 16:44:04 gomor $
 #
 # network::read Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1d19720513f5 $',
+      revision => '$Revision: 4a548f1412b7 $',
       tags => [ qw(unstable network read ethernet ip raw socket) ],
       attributes => {
          device => [ qw(device) ],
@@ -26,11 +26,15 @@ sub brik_properties {
       attributes_default => {
          layer => 2,
          max_read => 0,
+         family => 'ipv4',
+         protocol => 'tcp',
+         rtimeout => 5,
+         filter => '',
       },
       commands => {
-         open => [ qw(layer|OPTIONAL arg2|OPTIONAL arg3|OPTIONAL) ],
-         next => [ ],
-         next_until_timeout => [ ],
+         open => [ qw(layer|OPTIONAL device|OPTIONAL filter|OPTIONAL) ],
+         read_next => [ ],
+         read_until_timeout => [ ],
          close => [ ],
          has_timeout => [ ],
          reset_timeout => [ ],
@@ -48,54 +52,48 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         rtimeout => $self->global->rtimeout,
          device => $self->global->device,
-         family => $self->global->family,
-         protocol => $self->global->protocol,
       },
    };
 }
 
 sub open {
    my $self = shift;
-   my ($layer, $arg2, $arg3) = @_;
+   my ($layer, $device, $filter) = @_;
 
    if ($< != 0) {
       return $self->log->error("open: must be root to run");
    }
 
    $layer ||= 2;
+   $device ||= $self->device;
+   $filter ||= $self->filter;
 
    my $family = $self->family eq 'ipv6' ? 'ip6' : 'ip';
 
    my $protocol = defined($self->protocol) ? $self->protocol : 'tcp';
 
-   my $filter = $self->filter || '';
-
    my $dump;
    if ($layer == 2) {
-      $arg2 ||= $self->device;
-      $arg3 ||= $filter;
-
       $self->debug && $self->log->debug("open: timeoutOnNext: ".$self->rtimeout);
       $self->debug && $self->log->debug("open: filter: ".$filter);
 
       $dump = Net::Frame::Dump::Online2->new(
-         dev => $arg2,
+         dev => $device,
          timeoutOnNext => $self->rtimeout,
-         filter => $arg3,
+         filter => $filter,
       );
    }
    elsif ($self->layer != 3) {
       return $self->log->error("open: not implemented");
    }
 
-   $dump->start or return $self->log->error("open: error");
+   $dump->start or return $self->log->error("open: Net::Frame::Dump::Online2->start failed");
 
    return $self->_dump($dump);
 }
 
-sub next {
+sub read_next {
    my $self = shift;
 
    my $dump = $self->_dump;
@@ -108,7 +106,7 @@ sub next {
    return defined($next) ? $next : 0;
 }
 
-sub next_until_timeout {
+sub read_until_timeout {
    my $self = shift;
 
    my $dump = $self->_dump;
