@@ -1,5 +1,5 @@
 #
-# $Id: Whois.pm,v f9542919cc81 2015/02/21 10:40:01 gomor $
+# $Id: Whois.pm,v 18641f159fe5 2015/11/15 10:41:29 gomor $
 #
 # network::whois Brik
 #
@@ -11,10 +11,18 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: f9542919cc81 $',
+      revision => '$Revision: 18641f159fe5 $',
       tags => [ qw(unstable network whois) ],
+      attributes => {
+         rtimeout => [ qw(timeout) ],
+         last_server => [ qw(server) ],
+      },
+      attributes_default => {
+         rtimeout => 2,
+      },
       commands => {
          target => [ qw(domain|ip_address) ],
+         queried_server => [ ],
       },
       require_modules => {
          'Net::Whois::Raw' => [ ],
@@ -31,16 +39,36 @@ sub target {
       return $self->log->error($self->brik_help_run('target'));
    }
 
-   my $info = Net::Whois::Raw::whois($target)
-      or return $self->log->error("target: whois failed");
+   $Net::Whois::Raw::TIMEOUT = $self->rtimeout;
 
-   my $parse_string = Metabrik::String::Parse->new_from_brik($self) or return;
-   my $lines = $parse_string->to_array($info)
-      or return $self->log->error("target: to_array failed");
+   my $info;
+   my $server;
+   eval {
+      ($info, $server) = Net::Whois::Raw::whois($target)
+        or return $self->log->error("target: whois for target [$target] failed");
+   };
+   if ($@) {
+      chomp($@);
+      if ($@ =~ /(Connection timeout to \S+)/) {
+         $@ = $1;
+      }
+      return $self->log->error("target: whois failed with error [$@]");
+   }
+
+   my $sp = Metabrik::String::Parse->new_from_brik_init($self) or return;
+   my $lines = $sp->to_array($info) or return;
+
+   $self->last_server($server);
 
    return $lines;
 }
 
+sub queried_server {
+   my $self = shift;
+
+   return $self->last_server || 'undef';
+}
+
 1;
 
 __END__
