@@ -1,5 +1,5 @@
 #
-# $Id: Wps.pm,v 1db92d72d9a2 2015/02/16 07:14:38 gomor $
+# $Id: Wps.pm,v 1cb13feea4e0 2015/03/08 11:51:58 gomor $
 #
 # network::wps Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik::Network::Wlan);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1db92d72d9a2 $',
+      revision => '$Revision: 1cb13feea4e0 $',
       tags => [ qw(unstable wifi wlan network wps) ],
       commands => {
          brute_force_wps => [ qw(essid bssid|OPTIONAL) ],
@@ -63,7 +63,7 @@ sub brute_force_wps {
 
    my $cmd = "sudo reaver -i $monitor -b $bssid -vv";
 
-   my $shell_command = Metabrik::Shell::Command->new_from_brik($self);
+   my $shell_command = Metabrik::Shell::Command->new_from_brik($self) or return;
    my $r = $shell_command->system($cmd);
 
    $self->stop_monitor_mode;
