@@ -1,5 +1,5 @@
 #
-# $Id: Hostname.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Hostname.pm,v e5e3576f73a3 2015/11/10 09:17:44 gomor $
 #
 # string::hostname Brik
 #
@@ -11,8 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
-      tags => [ qw(unstable hostname string) ],
+      revision => '$Revision: e5e3576f73a3 $',
+      tags => [ qw(unstable hostname string fqdn domain) ],
       attributes => {
          hostname => [ qw(hostname) ],
       },
