@@ -1,5 +1,5 @@
 #
-# $Id: Json.pm,v 508610fe2b1a 2015/10/27 19:01:31 gomor $
+# $Id: Json.pm,v 037cb3d6d057 2015/11/21 09:41:00 gomor $
 #
 # string::json Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 508610fe2b1a $',
+      revision => '$Revision: 037cb3d6d057 $',
       tags => [ qw(unstable encode decode json) ],
       commands => {
          encode => [ qw($data_list|$data_hash) ],
@@ -41,7 +41,7 @@ sub encode {
    };
    if ($@) {
       chomp($@);
-      return $self->log->erro("decode: unable to decode JSON: $@");
+      return $self->log->error("encode: unable to encode JSON: $@");
    }
 
    return $encoded;
@@ -61,7 +61,7 @@ sub decode {
    };
    if ($@) {
       chomp($@);
-      return $self->log->erro("decode: unable to decode JSON: $@");
+      return $self->log->error("decode: unable to decode JSON: $@");
    }
 
    return $decoded;
