@@ -1,5 +1,5 @@
 #
-# $Id: Parse.pm,v 450625fc7a05 2015/01/16 06:33:09 gomor $
+# $Id: Parse.pm,v 887d85a7f604 2015/11/12 14:44:58 gomor $
 #
 # string::parse Brik
 #
@@ -11,12 +11,13 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 450625fc7a05 $',
+      revision => '$Revision: 887d85a7f604 $',
       tags => [ qw(unstable parse string) ],
       commands => {
          identify => [ qw(string) ],
          to_array => [ qw($data) ],
          to_matrix => [ qw($data) ],
+         split_by_blank_line => [ qw($data) ],
       },
    };
 }
@@ -29,6 +30,10 @@ sub to_array {
       return $self->log->error($self->brik_help_run('to_array'));
    }
 
+   if (ref($data)) {
+      return $self->log->error("to_array: data must be a SCALAR");
+   }
+
    my @array = split(/\n/, $data);
 
    return \@array;
@@ -42,7 +47,7 @@ sub to_matrix {
       return $self->log->error($self->brik_help_run('to_matrix'));
    }
 
-   my $array = $self->to_array($data);
+   my $array = $self->to_array($data) or return;
 
    my @matrix = ();
    for my $this (@$array) {
@@ -91,6 +96,37 @@ sub identify {
    return $identify;
 }
 
+sub split_by_blank_line {
+   my $self = shift;
+   my ($data) = @_;
+
+   if (! defined($data)) {
+      return $self->log->error($self->brik_help_run('split_by_blank_line'));
+   }
+
+   if (ref($data) ne 'ARRAY') {
+      return $self->log->error("split_by_blank_line: data must be an ARRAYREF");
+   }
+
+   my $new = [];
+   my @chunks = ();
+   for (@$data) {
+      if (/^\s*$/ && @$new > 0) {
+         push @chunks, $new;
+         $new = [];
+         next;
+      }
+      push @$new, $_;
+   }
+
+   # Read last lines before eof (no more blank lines can be found)
+   if (@$new > 0) {
+      push @chunks, $new;
+   }
+
+   return \@chunks;
+}
+
 1;
 
 __END__
