@@ -1,5 +1,5 @@
 #
-# $Id: Password.pm,v 6be0c79591ec 2015/01/07 06:39:25 gomor $
+# $Id: Password.pm,v cb06b0aa21d0 2015/11/07 18:01:20 gomor $
 #
 # string::password Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 6be0c79591ec $',
+      revision => '$Revision: cb06b0aa21d0 $',
       tags => [ qw(unstable password random) ],
       attributes => {
          charset => [ qw($character_list) ],
@@ -25,7 +25,7 @@ sub brik_properties {
       },
       commands => {
          generate => [ qw(length|OPTIONAL count|OPTIONAL) ],
-         prompt => [ ],
+         prompt => [ qw(string|OPTIONAL) ],
       },
       require_modules => {
          'String::Random' => [ ],
@@ -56,10 +56,13 @@ sub generate {
 
 sub prompt {
    my $self = shift;
+   my ($string) = @_;
+
+   $string ||= 'Password: ';
 
    my $password;
    while (1) {
-      my $this = Term::ReadPassword::read_password('password: ');
+      my $this = Term::ReadPassword::read_password($string);
       if (defined($this)) {
          $password = $this;
          last;
