@@ -1,5 +1,5 @@
 #
-# $Id: Package.pm,v 502f149de7be 2015/01/24 17:13:42 gomor $
+# $Id: Package.pm,v cb06b0aa21d0 2015/11/07 18:01:20 gomor $
 #
 # system::package Brik
 #
@@ -11,7 +11,7 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 502f149de7be $',
+      revision => '$Revision: cb06b0aa21d0 $',
       tags => [ qw(unstable system package) ],
       attributes => {
          _sp => [ qw(INTERNAL) ],
@@ -90,6 +90,12 @@ sub upgrade {
    return $self->_sp->upgrade;
 }
 
+sub list {
+   my $self = shift;
+
+   return $self->_sp->list;
+}
+
 1;
 
 __END__
