@@ -1,5 +1,5 @@
 #
-# $Id: Fork.pm,v b6b7ae90f8d0 2015/03/17 06:40:26 gomor $
+# $Id: Fork.pm,v 714d5f4c8eff 2015/11/22 11:38:52 gomor $
 #
 # worker::fork Brik
 #
@@ -12,7 +12,7 @@ use base qw(Metabrik);
 # Default attribute values put here will BE inherited by subclasses
 sub brik_properties {
    return {
-      revision => '$Revision: b6b7ae90f8d0 $',
+      revision => '$Revision: 714d5f4c8eff $',
       tags => [ qw(unstable worker fork process) ],
       attributes => {
          pid => [ qw(forked_process_id) ],
@@ -36,8 +36,6 @@ sub start {
    if ($pid) { # Father
       my $restore = $SIG{INT};
 
-      $SIG{CHLD} = "IGNORE";
-
       $self->pid($pid);
 
       $SIG{INT} = sub {
@@ -56,9 +54,8 @@ sub stop {
    my $self = shift;
 
    if ($self->pid) {
-      kill('QUIT', $self->pid);
-      # Not needed now, we just ignore SIGCHLD
-      #waitpid($self->pid, POSIX::WNOHANG());  # Cleanup zombie state
+      kill('TERM', $self->pid);
+      waitpid($self->pid, POSIX::WNOHANG());  # Cleanup zombie state in case it is dead
       $self->pid(undef);
    }
 
@@ -70,7 +67,9 @@ sub is_son_alive {
 
    my $pid = $self->pid;
    if (defined($pid)) {
+      waitpid($pid, POSIX::WNOHANG());  # Cleanup zombie state in case it is dead
       my $r = kill('ZERO', $pid);
+      $self->debug && $self->log->debug("is_son_alive: kill returned [$r] for pid [$pid]");
       if ($r) { # Son still alive
          return 1;
       }
